.. ucxdsa documentation master file, created by
   sphinx-quickstart on Fri Nov 14 14:56:56 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

UCXDSA documentation
====================

A collection of classes and functions for use in UC Berkeley Extension's 
Computer Science X404.1: Data Structures and Algorithms Class.

Version: |version|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   TODO
      
.. toctree::
   :maxdepth: 2
   :caption: Core Data Structures

   modules
       
.. toctree::
   :maxdepth: 2
   :caption: Linear Structures
   
   dsa.array.quick_start
   dsa.array

   dsa.stack.quick_start
   dsa.stack
   
   dsa.queue.quick_start
   dsa.queue

   dsa.deque.quick_start
   dsa.deque

.. toctree::
   :maxdepth: 2
   :caption: Linked List

   dsa.linkedlist.quick_start
   dsa.singlylinkedlist
   dsa.doublylinkedlist

.. toctree::
   :maxdepth: 2
   :caption: Hash

   dsa.hashset.quick_start
   dsa.hashset

   dsa.hashtable.quick_start
   dsa.hashtable

.. toctree::
   :maxdepth: 2
   :caption: Tree

   dsa.tree.quick_start
   dsa.tree
   dsa.heap.quick_start
   dsa.heap
   dsa.trie.quick_start
   dsa.trie

.. toctree::
   :maxdepth: 2
   :caption: Graph

   dsa.graph.quick_start
   dsa.graph

.. toctree::
   :maxdepth: 2
   :caption: Algorithms

   dsa.graph_traversal
   dsa.dijkstra
   dsa.prim
   dsa.huffman

.. toctree::
   :maxdepth: 2
   :caption: Helper Modules

   dsa.draw.quick_start
   dsa.draw
   dsa.pretty_print
   dsa.sorttools
   dsa.generators
